@@ -29,3 +29,6 @@ INSTALLED_APPS = [
 REDIS_METRICS_HOST = 'localhost'
 REDIS_METRICS_PORT = '6379'
 REDIS_METRICS_DB = 0
+REDIS_METRICS_PASSWORD = None
+REDIS_METRICS_SOCKET_TIMEOUT = None
+REDIS_METRICS_SOCKET_CONNECTION_POOL = None
